@@ -87,20 +87,13 @@ GVInbox::prepView ()
 }//GVInbox::prepView
 
 void
-GVInbox::refresh (bool full /*= false*/)
+GVInbox::refresh (const QDateTime &dtUpdate)
 {
     QMutexLocker locker(&mutex);
-    if (!bLoggedIn)
-    {
+    if (!bLoggedIn) {
         return;
     }
 
-    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-    QDateTime dtUpdate;
-    if (!full) {
-        dbMain.getLatestInboxEntry (dtUpdate);
-    }
-
     GVAccess &webPage = Singletons::getRef().getGVAccess ();
     QVariantList l;
 //    l += strSelectedMessages;
@@ -116,14 +109,28 @@ GVInbox::refresh (bool full /*= false*/)
     if (!webPage.enqueueWork (GVAW_getInbox, l, this,
             SLOT (getInboxDone (bool, const QVariantList &))))
     {
+        // Connect just so that the disconnect succeeds.
+        connect (&webPage, SIGNAL (oneInboxEntry (const GVInboxEntry &)),
+                  this   , SLOT   (oneInboxEntry (const GVInboxEntry &)));
         getInboxDone (false, l);
     }
 }//GVInbox::refresh
 
+void
+GVInbox::refresh ()
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    QDateTime dtUpdate;
+    dbMain.getLatestInboxEntry (dtUpdate);
+
+    refresh(dtUpdate);
+}//GVInbox::refresh
+
 void
 GVInbox::refreshFullInbox ()
 {
-    refresh (true);
+    QDateTime dtUpdate;
+    refresh(dtUpdate);
 }//GVInbox::refreshFullInbox
 
 void
@@ -154,10 +161,9 @@ GVInbox::getInboxDone (bool, const QVariantList &params)
     dbMain.setQuickAndDirty (false);
 
     GVAccess &webPage = Singletons::getRef().getGVAccess ();
-    bool rv = disconnect (
+    disconnect (
         &webPage, SIGNAL (oneInboxEntry (const GVInboxEntry &)),
          this   , SLOT   (oneInboxEntry (const GVInboxEntry &)));
-    Q_ASSERT(rv); Q_UNUSED(rv);
 
     prepView ();
 
@@ -169,8 +175,7 @@ void
 GVInbox::onInboxSelected (const QString &strSelection)
 {
     QMutexLocker locker(&mutex);
-    if (!bLoggedIn)
-    {
+    if (!bLoggedIn) {
         return;
     }
 
