@@ -59,6 +59,8 @@ ObserverFactory::~ObserverFactory ()
 bool
 ObserverFactory::init ()
 {
+    bool rv;
+
     // Observer for Telepathy on desktop Linux and Maemo 5
 #if TELEPATHY_CAPABLE
     clientRegistrar = ClientRegistrar::create();
@@ -83,9 +85,9 @@ ObserverFactory::init ()
     AbstractClientPtr appr = (AbstractClientPtr) myobserver;
     clientRegistrar->registerClient(appr, "QGVStreamObserver");
 
-    QObject::connect (
-            myobserver, SIGNAL (status(const QString &, int)),
-            this      , SIGNAL (status(const QString &, int)));
+    rv = connect (myobserver, SIGNAL (status(const QString &, int)),
+                  this      , SIGNAL (status(const QString &, int)));
+    Q_ASSERT(rv);
 
     listObservers += (IObserver*) myobserver;
 #endif
@@ -94,9 +96,9 @@ ObserverFactory::init ()
 #if LINUX_DESKTOP || defined(Q_WS_WIN32)
     SkypeObserver *skypeObs = new SkypeObserver ();
 
-    QObject::connect (
-        skypeObs, SIGNAL (status(const QString &, int)),
-        this    , SIGNAL (status(const QString &, int)));
+    rv = connect (skypeObs, SIGNAL (status(const QString &, int)),
+                  this    , SIGNAL (status(const QString &, int)));
+    Q_ASSERT(rv);
 
     listObservers += (IObserver*) skypeObs;
 #endif
@@ -109,10 +111,11 @@ ObserverFactory::startObservers (const QString &strContact,
                                        QObject *receiver  ,
                                  const char    *method    )
 {
+    bool rv;
     foreach (IObserver *observer, listObservers)
     {
-        QObject::connect (observer, SIGNAL (callStarted()),
-                          receiver, method);
+        rv = connect (observer, SIGNAL (callStarted()),
+                      receiver, method);
         observer->startMonitoring (strContact);
     }
 }//ObserverFactory::createObservers
